# shfilters: Simple header filters.
# array of [$name, lc($header), $must_match, $must_not_match]
# $must_match and $but_does_not_match may be undef

@::shfilters=(
	["Spamtool-Demo_X-Mailer", "x-mailer",
     qr/^Microsoft Outlook Express [0-9.]+ DM$/, undef],
	["Spamtool", "x-mailer",
     qr/^Microsoft Outlook Express [0-9.]+ DM$
       |^PHPBulkEmailer/x, undef],
	["Fake_X-Mailer", "x-mailer",
     qr/^[a-z]+(?: [a-z]+){1,2}(?: \d.\d+)?$/, undef],
	["Fake_Content-Type", "content-type",
	 qr/;\s*charset=/,qr/;\s*charset="?$::charsetre\b"?/i]
);


# received chain patterns.
# array of [ $match_current, $match_last ]
# where $match_* is a hash describing the contents of the sub-records
# in the current and the previous received header
#
# a header is trusted if the previous header is trusted  and there is a
# record matching both the current and the previous header in each
# sub-record.
#
# For the first received line, the "previous header" is set to
# ("Mail-Host" => "...").

@::received_chain=(
	[	{	"Mail-Host" => qr/be\d+(?:\.lrz)?\Q.7eggert.dyndns.org\E/
		},{	"Mail-Host" => qr/\Q...\E|be\d+(?:\.lrz)?\Q.7eggert.dyndns.org\E/,
	}],
	[	{	"Mail-Host" => "localhost",
			"Mail-Protocol" => "POP3",
			"Source-HELO" => qr/\Qpop3.web.de\E|localhost/
		},{	"Mail-Host" => qr/be3(?:\.lrz)?\Q.7eggert.dyndns.org\E/
	}],
	[	{	"Mail-Host" => qr/mx\d+\Q.web.de\E/
		},{	"Mail-Host" => "localhost"
	}],
	[	{	"Mail-Host" => "\Qmx0.gmx.net\E",
			"Mail-Protocol" => "SMTP"
		},{	"Mail-Host" => qr/mx\d+\Q.web.de\E/,
			"Source-IP" => qr/\Q213.165.6\E(?:[45]\.\d+|6\.(?:\d\d|1[01]\d|12[0-7]))\E/
	}],
	[	{	"Mail-Host" => "localhost",
			"Mail-Protocol" => "POP3",
			"Source-IP" => "\Q127.0.0.1\E"
		},{	"Mail-Host" => "\Qbe3.7eggert.dyndns.org\E"
	}],
	[	{	"Mail-Host" => qr/rzdspc\d\Q.informatik.uni-hamburg.de\E/
		},{	"Mail-Host" => qr/localhost|rzdspc\d\Q.informatik.uni-hamburg.de\E/
	}],
	[	{	"Mail-Host" => qr/mx\d+\Q.rrz.uni-hamburg.de\E/
		},{	"Mail-Host" => qr/rzdspc\d\Q.informatik.uni-hamburg.de\E/
	}],
	[	{	"Mail-Host" => qr/\Qrzaixsrv2.rrz.uni-hamburg.de\E|
	                          \Qws-ham1.win-ip.dfn.de\E/x
		},{	"Mail-Host" => qr/\Qrzdspc1.informatik.uni-hamburg.de\E|
		                      \Qmx01.rrz.uni-hamburg.de\E/x,
			"Source-rDNS" => qr/\Qws-ham1.win-ip.dfn.de\E|
			                    \Qrzaixsrv2.rrz.uni-hamburg.de\E/x
	}]
);


# location of the domain- and digest databases.


# domains belonging to spammers
#
# comments start with hash ('#')

$::DOMAINLIST_BAD  = "/home/7eggert/.config/fsmtpd/spammers.domain";

# spammer page if hosted by lycos, geocities etc.
# (members.tripod.com.br/foobar/)

$::USERPAGELIST    = "/home/7eggert/.config/fsmtpd/spammers.userpages";

$::IP_BLOCKS = "/home/7eggert/.config/fsmtpd/block.ipranges";

# do not list these:
$::DOMAINLIST_GOOD = "/home/7eggert/.config/fsmtpd/goodurl.domain";

# these domains don't exist
$::DOMAINLIST_NX   = "/home/7eggert/.config/fsmtpd/nxdomain";

# Your IP range blocks
#
# format: firstip lastip description (may include whiteapace)

# this is the list of known malware,
#
# format: malware_name digest_string
#
# Example:
# W32_FunLove.4099 md5:264a86439f4b2f77203e91a04d28dd53 sha1:e8efde06224816981cef8b0338d70180568d8d2d

$::DIGESTLIST      = "/home/7eggert/.config/fsmtpd/malware.dglist";

# digest binary.
# Will be called with the absolute filename as the final argument
#
# must return
#  "filename hash-string"
# or
# ( "hash-string" with filename not being the first part of hash-string )
#
# example:
# @::DGLIST_BIN=("/usr/local/bin/sha1sum-wrapper");
#
# where /usr/local/bin/sha1sum-wrapper contains
# |#!/bin/sh
# |/usr/bin/sha1sum "$@"|sed -e's/ .*$//'

@::DGLIST_BIN=("/usr/local/bin/dglist","-Hmd5","-Hsha1");



# re for matching hosters like tripod, geocities etc.
#
# the last matching parens ($+) must return the name of tha page being hosted.

$::userpagere=qr,(?:http:/+)?members\.tripod\.\w+(?:\.\w+)?/(\w+)(?:/|$),i;
# return true to make perl happy

1;